@@ -14,7 +14,7 @@ def rgb_to_ansi(colour):
     """
     Convert a string containing an RGB colour to ANSI escapes
     """
-    if not colour or not colour.startswith('#'):
+    if not colour or not colour.startswith("#"):
         return
 
     r, g, b = colour[1:3], colour[3:5], colour[5:7]
@@ -22,25 +22,22 @@ def rgb_to_ansi(colour):
     if not len(r) == len(g) == len(b) == 2:
         return
 
-    return '\33[38;2;{!s};{!s};{!s}m'.format(
-        int(r, 16), int(g, 16), int(b, 16)
-    )
+    return "\33[38;2;{!s};{!s};{!s}m".format(int(r, 16), int(g, 16), int(b, 16))
 
 
 class DefaultFormatter:
     def __init__(
         self,
-        date_format='%Y-%m-%d',
-        time_format='%H:%M',
-        dt_separator=' ',
-        tz_override=None
+        date_format="%Y-%m-%d",
+        time_format="%H:%M",
+        dt_separator=" ",
+        tz_override=None,
     ):
         self.date_format = date_format
         self.time_format = time_format
         self.dt_separator = dt_separator
         self.datetime_format = dt_separator.join(
-            filter(bool,
-                   (date_format, time_format))
+            filter(bool, (date_format, time_format))
         )
 
         self.tz = tz_override or tzlocal()
@@ -56,37 +53,42 @@ class DefaultFormatter:
     def compact(self, todo):
         return self.compact_multiple([todo])
 
-    def compact_multiple(self, todos):
+    def compact_multiple(self, todos, hide_list=False):
         table = []
         for todo in todos:
             completed = "X" if todo.is_completed else " "
-            percent = todo.percent_complete or ''
+            percent = todo.percent_complete or ""
             if percent:
                 percent = " ({}%)".format(percent)
             priority = self.format_priority_compact(todo.priority)
 
             due = self.format_datetime(todo.due)
-            now = (self.now
-                   if isinstance(todo.due, datetime.datetime)
-                   else self.now.date())
+            now = (
+                self.now if isinstance(todo.due, datetime.datetime) else self.now.date()
+            )
             if todo.due and todo.due <= now and not todo.is_completed:
-                due = click.style(due, fg='red')
+                due = click.style(due, fg="red")
 
-            recurring = '⟳' if todo.is_recurring else ''
+            recurring = "⟳" if todo.is_recurring else ""
 
-            table.append([
-                todo.id,
-                "[{}]".format(completed),
-                priority,
-                '{} {}'.format(due, recurring),
-                "{} {}{}".format(
-                    todo.summary,
-                    self.format_database(todo.list),
-                    percent,
-                ),
-            ])
+            if hide_list:
+                summary = "{} {}".format(todo.summary, percent,)
+            else:
+                summary = "{} {}{}".format(
+                    todo.summary, self.format_database(todo.list), percent,
+                )
 
-        return tabulate(table, tablefmt='plain')
+            table.append(
+                [
+                    todo.id,
+                    "[{}]".format(completed),
+                    priority,
+                    "{} {}".format(due, recurring),
+                    summary,
+                ]
+            )
+
+        return tabulate(table, tablefmt="plain")
 
     def _columnize_text(self, label, text):
         """Display text, split text by line-endings, on multiple colums,"""
@@ -115,53 +117,50 @@ class DefaultFormatter:
         :param Todo todo: The todo component.
         """
         extra_rows = []
-        extra_rows += self._columnize_text('Description', todo.description)
-        extra_rows += self._columnize_text('Location', todo.location)
+        extra_rows += self._columnize_text("Description", todo.description)
+        extra_rows += self._columnize_text("Location", todo.location)
 
         if extra_rows:
-            return '{}\n\n{}'.format(
-                self.compact(todo), tabulate(extra_rows, tablefmt='plain')
+            return "{}\n\n{}".format(
+                self.compact(todo), tabulate(extra_rows, tablefmt="plain")
             )
         return self.compact(todo)
 
     def format_datetime(self, dt):
         if not dt:
-            return ''
+            return ""
         elif isinstance(dt, datetime.datetime):
             return dt.strftime(self.datetime_format)
         elif isinstance(dt, datetime.date):
             return dt.strftime(self.date_format)
 
     def parse_priority(self, priority):
-        if priority is None or priority == '':
+        if priority is None or priority == "":
             return None
-        if priority == 'low':
+        if priority == "low":
             return 9
-        elif priority == 'medium':
+        elif priority == "medium":
             return 5
-        elif priority == 'high':
+        elif priority == "high":
             return 4
-        elif priority == 'none':
+        elif priority == "none":
             return 0
         else:
-            raise ValueError(
-                'Priority has to be one of low, medium,'
-                ' high or none'
-            )
+            raise ValueError("Priority has to be one of low, medium, high or none")
 
     def format_priority(self, priority):
         if not priority:
-            return 'none'
+            return "none"
         elif 1 <= priority <= 4:
-            return 'high'
+            return "high"
         elif priority == 5:
-            return 'medium'
+            return "medium"
         elif 6 <= priority <= 9:
-            return 'low'
+            return "low"
 
     def format_priority_compact(self, priority):
         if not priority:
-            return ''
+            return ""
         elif 1 <= priority <= 4:
             return "!!!"
         elif priority == 5:
@@ -174,11 +173,7 @@ class DefaultFormatter:
             return None
 
         rv = self._parse_datetime_naive(dt)
-        return (
-            rv.replace(tzinfo=self.tz)
-            if isinstance(rv, datetime.datetime)
-            else rv
-        )
+        return rv.replace(tzinfo=self.tz) if isinstance(rv, datetime.datetime) else rv
 
     def _parse_datetime_naive(self, dt):
         """Parse dt and returns a naive datetime or a date"""
@@ -194,31 +189,33 @@ class DefaultFormatter:
 
         try:
             return datetime.datetime.combine(
-                self.now.date(),
-                datetime.datetime.strptime(dt, self.time_format).time()
+                self.now.date(), datetime.datetime.strptime(dt, self.time_format).time()
             )
         except ValueError:
             pass
 
         rv, pd_ctx = self._parsedatetime_calendar.parse(dt)
         if not pd_ctx.hasDateOrTime:
-            raise ValueError('Time description not recognized: {}'.format(dt))
+            raise ValueError("Time description not recognized: {}".format(dt))
         return datetime.datetime.fromtimestamp(mktime(rv))
 
     def format_database(self, database):
-        return '{}@{}'.format(
-            rgb_to_ansi(database.colour) or '', click.style(database.name)
+        return "{}@{}".format(
+            rgb_to_ansi(database.colour) or "", click.style(database.name)
         )
 
 
 class HumanizedFormatter(DefaultFormatter):
     def format_datetime(self, dt):
         if not dt:
-            return ''
+            return ""
 
-        rv = humanize.naturaltime(self.now - dt)
-        if ' from now' in rv:
-            rv = 'in {}'.format(rv[:-9])
+        if isinstance(dt, datetime.datetime):
+            rv = humanize.naturaltime(self.now - dt)
+            if " from now" in rv:
+                rv = "in {}".format(rv[:-9])
+        elif isinstance(dt, datetime.date):
+            rv = humanize.naturaldate(dt)
 
         return rv
 
@@ -239,7 +236,7 @@ class PorcelainFormatter(DefaultFormatter):
     def compact(self, todo):
         return json.dumps(self._todo_as_dict(todo), indent=4, sort_keys=True)
 
-    def compact_multiple(self, todos):
+    def compact_multiple(self, todos, hide_list=False):
         data = [self._todo_as_dict(todo) for todo in todos]
         return json.dumps(data, indent=4, sort_keys=True)
 
@@ -253,7 +250,7 @@ class PorcelainFormatter(DefaultFormatter):
             if int(priority) in range(0, 10):
                 return int(priority)
             else:
-                raise ValueError('Priority has to be in the range 0-9')
+                raise ValueError("Priority has to be in the range 0-9")
         except ValueError as e:
             raise click.BadParameter(e)
 
@@ -262,6 +259,8 @@ class PorcelainFormatter(DefaultFormatter):
 
     def format_datetime(self, date):
         if date:
+            if not hasattr(date, "timestamp"):
+                date = datetime.datetime.fromordinal(date.toordinal())
             return int(date.timestamp())
         else:
             return None
